Auto-generated Langfuse REST API client.
Generated from the vendored OpenAPI spec (openapi.yml) using progenitor.
Modules
- builder
- Types for composing operation parameters.
- prelude
- Items consumers will typically use such as the Client.
- types
- Types used as operation parameters and responses.
Structs
- Byte
Stream - Untyped byte stream used for both success and error responses.
- Client
- Client for langfuse
- Response
Value - Typed value returned by generated client methods.
Enums
- Error
- Error produced by generated client methods.